Changelog
=========

2018.8.0
--------

:data: 2018-08-09

* Add docker integration for running tests
* Add travis CI integration
* Add datasource health extension and tests

2018.4.0
--------

:date: 2018-04-03

Updated python-dockerflow to 2018.4.0 to fix a
backward-compatibility issue with a dependency.

2018.3.0
--------

:date: 2018-03-08

Copy ActiveData query runner from our Redash fork. Originally written
by Kyle Lahnakoski at https://github.com/klahnakoski/ActiveData-redash-query-runner.

2018.2.3
--------

:date: 2018-02-28

First release that provides automatic support for Dockerflow_.

.._Dockerflow: http://python-dockerflow.readthedocs.io/
